# OpenfoodLib 

## Introduction

This library is a wrapper to interact with OpenFoodFacts API.

## Install the library

The librabry is available on pypy, to install it, run the following command : 

`python -m pip install openfoodlib`

## Use the library

For now, only read actions are availables, example can be found [here](./example.py)


